# monte-solver

Monte Carlo dissolver

## OpenMM 

Installing OpenMM from PyPi is nice to avoid conda, but you need to have numpy<2 installed. In case
of errors, you may run: 

```bash
pip install "numpy<2"
```